@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.74 2004/07/10 11:48:50 kevinv Exp $
+ $Id: battstat_applet.c,v 1.80 2004/08/16 08:44:39 davyd Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,8 +55,6 @@
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
-#include <egg-screen-help.h>
-
 /*#include <status-docklet.h>*/
 
 #include "battstat.h"
@@ -83,6 +81,9 @@ static const BonoboUIVerb battstat_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
+#define AC_POWER_STRING _("System is running on AC power")
+#define DC_POWER_STRING _("System is running on battery power")
+
 int pixel_offset_top[]={ 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5 };
 int pixel_top_length[]={ 2, 3, 4, 4, 4, 4, 4, 4, 4, 4, 3, 2 };
 int pixel_offset_bottom[]={ 38, 38, 39, 39, 39, 39, 39, 39, 39, 39, 38, 38 };
@@ -223,10 +224,9 @@ GdkColor darkred[] = {
 };
 
 #if defined(__NetBSD__) || defined(__OpenBSD__)
-struct apm_power_info apminfo;
-#else
-struct apm_info apminfo;
+typedef apm_power_info apm_info;
 #endif
+struct apm_info apminfo;
 
 #ifdef __linux__
 struct acpi_info acpiinfo;
@@ -349,17 +349,77 @@ apm_readinfo (PanelApplet *applet, ProgressData * battstat)
 
 /* } */
 
-static char *get_remaining (int time)
+static char *get_remaining (apm_info apminfo)
 {
-	int hours = time / 60;
-	int mins  = time % 60;
-	
-	if (time == -1)
-		return g_strdup_printf(_("charged"));
-	else if (time < 0)
-		return g_strdup_printf(_("..."));
+	int time;
+	int hours;
+	int mins;
+	guint acline_status;
+	guint batt_life;
+
+#ifdef __FreeBSD__
+	acline_status = apminfo.ai_acline ? 1 : 0;
+	time = apminfo.ai_batt_time;
+	batt_life = apminfo.ai_batt_life;
+#elif defined (__NetBSD__) || defined(__OpenBSD__)
+	acline_status = apminfo.ac_state ? 1 : 0;
+	time = apminfo.battery_time;
+	batt_life = apminfo.battery_life;
+#elif __linux__
+	acline_status = apminfo.ac_line_status ? 1 : 0;
+	time = apminfo.battery_time;
+	batt_life = apminfo.battery_percentage;
+#endif
+
+	if (batt_life > 100) batt_life = 100;
+
+	hours = time / 60;
+	mins = time % 60;
+
+	if (acline_status && batt_life == 100)
+		return g_strdup_printf (_("Battery charged (%d%%)"), batt_life);
+	else if (time < 0 && !acline_status)
+		return g_strdup_printf (_("Unknown time (%d%%) remaining"), batt_life);
+	else if (time < 0 && acline_status)
+		return g_strdup_printf (_("Unknown time (%d%%) till charged"), batt_life);
 	else
-		return g_strdup_printf(_("%d hours %d minutes remaining"), hours, mins);	
+		if (hours == 0)
+			if (!acline_status)
+				return g_strdup_printf (ngettext (
+						"%d minute (%d%%) remaining",
+						"%d minutes (%d%%) remaining",
+						mins), mins, batt_life);
+			else
+				return g_strdup_printf (ngettext (
+						"%d minute till charged (%d%%)",
+						"%d minutes till charged (%d%%)",
+						mins), mins, batt_life);
+		else if (mins == 0)
+			if (!acline_status)
+				return g_strdup_printf (ngettext (
+						"%d hour (%d%%) remaining",
+						"%d hours (%d%%) remaining",
+						hours), hours, batt_life);
+			else
+				return g_strdup_printf (ngettext (
+						"%d hour (%d%%) till charged (%d%%)",
+						"%d hours (%d%%) till charged (%d%%)",
+						hours), hours, batt_life);
+		else
+			if (!acline_status)
+				/* TRANSLATOR: "%d %s %d %s" are "%d hours %d minutes"
+				 * Swap order with "%2$s %2$d %1$s %1$d if needed */
+				return g_strdup_printf (_("%d %s %d %s (%d%%) remaining"),
+						hours, ngettext ("hour", "hours", hours),
+						mins, ngettext ("minute", "minutes", mins),
+						batt_life);
+			else
+				/* TRANSLATOR: "%d %s %d %s" are "%d hours %d minutes"
+				 * Swap order with "%2$s %2$d %1$s %1$d if needed */
+				return g_strdup_printf (_("%d %s %d %s till charged (%d%%)"),
+						hours, ngettext ("hour", "hours", hours),
+						mins, ngettext ("minute", "minutes", mins),
+						batt_life);
 }
 	
 gint
@@ -382,19 +442,6 @@ pixmap_timeout( gpointer data )
   GtkWidget *hbox, *image, *label, *dialog;
   GdkPixbuf *pixbuf;
   
-  gchar *status[]={
-    /* The following four messages will be displayed as tooltips over
-     the battery meter.  
-     High = The APM BIOS thinks that the battery charge is High.*/
-    gettext_noop ("High"),
-    /* Low = The APM BIOS thinks that the battery charge is Low.*/
-    gettext_noop ("Low"),
-    /* Critical = The APM BIOS thinks that the battery charge is Critical.*/
-    gettext_noop ("Critical"),
-    /* Charging = The APM BIOS thinks that the battery is recharging.*/
-    gettext_noop ("Charging")
-  };
-
   if (DEBUG) g_print("pixmap_timeout()\n");
 
   /*
@@ -474,8 +521,12 @@ pixmap_timeout( gpointer data )
    ) {
       /* Warn that battery dropped below red_val */
       if(battery->lowbattnotification) {
-	 new_string = get_remaining (apminfo.battery_time);
-	 new_label = g_strdup_printf (_("Your battery is running low (%d%%, %s). You should recharge your battery to avoid losing your work."), batt_life, new_string);
+	 new_string = get_remaining (apminfo);
+	 new_label = g_strdup_printf (
+			 "<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s. %s",
+			 _("Your battery is running low"),
+			 new_string,
+			 _("To avoid losing work please power off, suspend or plug your laptop in."));
 	 g_free (new_string);
 	 battery->lowbattnotificationdialog = gtk_dialog_new_with_buttons (
 			 _("Battery Notice"),
@@ -499,9 +550,14 @@ pixmap_timeout( gpointer data )
 	 gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 6);
 	 label = gtk_label_new (new_label);
 	 gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	 g_free (new_label);
 	 gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 6);
 	 gtk_container_add (GTK_CONTAINER (GTK_DIALOG (battery->lowbattnotificationdialog)->vbox), hbox);
+	 
+	 gtk_window_set_keep_above (GTK_WINDOW (battery->lowbattnotificationdialog), TRUE);
+	 gtk_window_stick (GTK_WINDOW (battery->lowbattnotificationdialog));
+			
 	 gtk_widget_show_all (battery->lowbattnotificationdialog);
     
          if(battery->beep)
@@ -524,6 +580,7 @@ pixmap_timeout( gpointer data )
       /* Inform that battery now fully charged */
       gnome_triggers_do ("", NULL, "battstat_applet", "BatteryFull", NULL);
       if(battery->fullbattnot) {
+	 gchar *new_label;
 	 dialog = gtk_dialog_new_with_buttons (
 			 _("Battery Notice"),
 			 NULL,
@@ -544,8 +601,12 @@ pixmap_timeout( gpointer data )
 	 image = gtk_image_new_from_pixbuf (pixbuf);
 	 g_object_unref (pixbuf);
 	 gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 6);
-	 label = gtk_label_new (_("Your battery is now fully recharged."));
+	 new_label = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>",
+			 _("Your battery is now fully recharged"));
+	 label = gtk_label_new (new_label);
+	 g_free (new_label);
 	 gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	 gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	 gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 6);
 	 gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), hbox);
 	 gtk_widget_show_all (dialog);
@@ -587,18 +648,24 @@ pixmap_timeout( gpointer data )
       /* Update the tooltip */
 
       if(!battery->showbattery && !battery->showpercent) {
+	 gchar *new_string;
+	 new_string = get_remaining (apminfo);
+
 	 if(acline_status == 0) {
-		new_label = g_strdup_printf (_("System is running on battery power\nBattery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));
+		new_label = g_strdup_printf ("%s\n%s",
+				DC_POWER_STRING,
+				new_string);
 	 } else {
-		new_label = g_strdup_printf (_("System is running on AC power\nBattery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));
+		new_label = g_strdup_printf ("%s\n%s",
+				AC_POWER_STRING,
+				new_string);
 	 }
+	 g_free (new_string);
       } else {
 	 if(acline_status == 0) {
-		new_label = g_strdup (_("System is running on battery power"));
+		new_label = g_strdup (DC_POWER_STRING);
 	 } else {
-		new_label = g_strdup (_("System is running on AC power"));
+		new_label = g_strdup (AC_POWER_STRING);
 	 }
       }
 
@@ -609,6 +676,7 @@ pixmap_timeout( gpointer data )
       g_free (new_label);
    
       /* Update the battery meter, tooltip and label */
+      /* FIXME: 2.9 feature, add optional time here */
       
       if (batterypresent) {
 	 new_label = g_strdup_printf ("%d%%", batt_life);
@@ -732,23 +800,20 @@ pixmap_timeout( gpointer data )
 	 }
       }
       
-      if (batt_state != 3)
-	      rem_time = get_remaining(apminfo.battery_time);
-      else
-	      rem_time = g_strdup(_(status[batt_state]));
+      rem_time = get_remaining(apminfo);
       
       if (battery->showstatus == 0) {
 	 if (batterypresent) {
 	    if(acline_status == 0) {
 			/* This string will display as a tooltip over the battery frame
-			 when the computer is using battery power.*/
-		new_string = g_strdup_printf (_("System is running on battery power. Battery: %d%% (%s)"),
-			batt_life, rem_time);
+			 when the computer is using battery power. */
+		new_string = g_strdup_printf ("%s\n%s",
+				DC_POWER_STRING, rem_time);
 	    } else {
 			/* This string will display as a tooltip over the battery frame
-			 when the computer is using AC power.*/
-		new_string = g_strdup_printf (_("System is running on AC power. Battery: %d%% (%s)"),
-			batt_life, rem_time);
+			 when the computer is using AC power. */
+		new_string = g_strdup_printf ("%s\n%s",
+			AC_POWER_STRING, rem_time);
 	    }
 	 } else {
 	    if(acline_status == 0) {
@@ -756,12 +821,16 @@ pixmap_timeout( gpointer data )
 			 battery frame when the computer is using battery
 			 power and the battery isn't present. Not a
 			 possible combination, I guess... :)*/
-		new_string = g_strdup (_("System is running on battery power. Battery: Not present"));
+		new_string = g_strdup_printf ("%s\n%s",
+				DC_POWER_STRING,
+				_("Battery status unknown"));
 	    } else {
 			/* This string will display as a tooltip over the
 			 battery frame when the computer is using AC
 			 power and the battery isn't present.*/
-		new_string = g_strdup (_("System is running on AC power. Battery: Not present"));
+		new_string = g_strdup_printf ("%s\n%s",
+				AC_POWER_STRING,
+				_("No battery present"));
 	    }
 	 }
       } else {
@@ -769,12 +838,11 @@ pixmap_timeout( gpointer data )
 		    /* Displayed as a tooltip over the battery meter when there is
 		     a battery present. %d will hold the current charge and %s will
 		     contains a string of the time remaining */
-		new_string = g_strdup_printf ((_("Battery: %d%% (%s)")),
-		    batt_life, rem_time);
+		new_string = g_strdup (rem_time);
 	 } else {
 		     /* Displayed as a tooltip over the battery meter when no
 		      battery is present. */
-		new_string = g_strdup (_("Battery: Not present"));
+		new_string = g_strdup (_("No battery present"));
 	 }
       }
       
@@ -789,8 +857,6 @@ pixmap_timeout( gpointer data )
 			   gettext(new_string),
 			   NULL);
       g_free (new_string);
-      
-      if (DEBUG) printf("Percent: %d, Status: %s\n", batt_life, status[batt_state]);
    }
 
    battery->last_charging = charging;
@@ -819,6 +885,7 @@ destroy_applet (GtkWidget *widget, gpointer data)
    gtk_timeout_remove (pdata->pixtimer);
    pdata->pixtimer = 0;
    pdata->applet = NULL;
+   g_object_unref(G_OBJECT (pdata->testpixgc));
    g_object_unref(G_OBJECT (pdata->pixgc));
    g_object_unref(pdata->ac_tip);
    g_object_unref(pdata->progress_tip);
@@ -899,7 +966,7 @@ help_cb (BonoboUIComponent *uic,
 {
     GError *error = NULL;
 
-    egg_help_display_on_screen (
+    gnome_help_display_on_screen (
 		"battstat", NULL,
 		gtk_widget_get_screen (battstat->applet),
 		&error);
@@ -914,7 +981,7 @@ help_cb (BonoboUIComponent *uic,
 void
 helppref_cb (PanelApplet *applet, gpointer data)
 {
-  /* FIXME: use (egg|gnome)_screen_help_display
+  /* FIXME: use gnome_help_display_on_screen()
        GnomeHelpMenuEntry help_entry = {
       "battstat_applet", "index.html#BATTSTAT_PREFS"
    };
@@ -975,6 +1042,7 @@ about_cb (BonoboUIComponent *uic,
 	_("Jorgen Pehrson <jp@spektr.eu.org>"), 
 	"Lennart Poettering <lennart@poettering.de> (Linux ACPI support)",
 	"Seth Nickell <snickell@stanford.edu> (GNOME2 port)",
+	"Davyd Madeley <davyd@ucc.asn.au>",
 	NULL
    };
 
@@ -1007,7 +1075,7 @@ about_cb (BonoboUIComponent *uic,
 				/* The long name of the applet in the About dialog.*/
 				_("Battery Charge Monitor"), 
 				VERSION,
-				_("(C) 2000 The Gnulix Society, (C) 2002 Free Software Foundation"),
+				_("(C) 2000 The Gnulix Society, (C) 2002-2004 Free Software Foundation"),
 				_("This utility shows the status of your laptop battery."),
 				authors,
 				documenters,
@@ -1038,17 +1106,7 @@ change_orient (PanelApplet       *applet,
    guint acline_status;
    guint batt_state;
    guint batt_life;
-   gchar *status[]={
-      /* The following four messages will be displayed as tooltips over
-       the battery meter.  
-       High = The APM BIOS thinks that the battery charge is High.*/
-      gettext_noop ("High"),
-      /* Low = The APM BIOS thinks that the battery charge is Low.*/
-      gettext_noop ("Low"),
-      /* Critical = The APM BIOS thinks that the battery charge is Critical.*/
-      gettext_noop ("Critical"),
-      /* Charging = The APM BIOS thinks that the battery is recharging.*/
-      gettext_noop ("Charging")};
+   gchar *time_string;
 
    battstat->orienttype = orient;
    
@@ -1072,22 +1130,23 @@ change_orient (PanelApplet       *applet,
    batt_state = 0;
    batt_life = 100;
 #endif
+   time_string = get_remaining (apminfo);
    if(batt_state > 3) batt_state = 0;
    if(batt_life > 100) batt_life = 100;
 
    switch(battstat->orienttype) {
     case PANEL_APPLET_ORIENT_UP:
     case PANEL_APPLET_ORIENT_DOWN:
-      if(battstat->panelsize<40)
+      if(battstat->panelsize<46)
 	battstat->horizont=TRUE;
       else
 	battstat->horizont=FALSE;
       break;
     case PANEL_APPLET_ORIENT_LEFT:
     case PANEL_APPLET_ORIENT_RIGHT:
-      if (battstat->panelsize>=60)
-	battstat->horizont=TRUE;
-      else
+      if ( (!battstat->showpercent && battstat->panelsize>=60) || (battstat->showpercent && battstat->panelsize>=90) )
+	  battstat->horizont=TRUE;
+      else 
 	battstat->horizont=FALSE;
       break;
    }
@@ -1112,32 +1171,33 @@ change_orient (PanelApplet       *applet,
 	 if(acline_status == 0) {
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power and the battery meter
-		      and percent meter is hidden by the user.*/
-		new_label = g_strdup_printf (_("System is running on battery power. Battery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));
+	  	      and percent meter is hidden by the user. */
+		new_label = g_strdup_printf ("%s\n%s",
+				DC_POWER_STRING, time_string);
 	 } else {
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power and the battery meter
-		      and percent meter is hidden by the user.*/
-		new_label = g_strdup_printf (_("System is running on AC power. Battery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));      
+		      and percent meter is hidden by the user. */
+		new_label = g_strdup_printf ("%s\n%s",
+				AC_POWER_STRING, time_string);
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
 	 g_free (new_label);
+	 g_free (time_string);
       } else {
 	 if(acline_status == 0) {
 	    /* 0 = Battery power */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power.*/
-		new_label = g_strdup (_("System is running on battery power"));
+		new_label = g_strdup (DC_POWER_STRING);
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power.*/
-		new_label = g_strdup(_("System is running on AC power"));
+		new_label = g_strdup(AC_POWER_STRING);
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
@@ -1198,16 +1258,16 @@ change_orient (PanelApplet       *applet,
 	    /* 0 = Battery power */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power and the battery meter
-		      and percent meter is hidden by the user.*/
-		new_label = g_strdup_printf (_("System is running on battery power\nBattery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));
+		      and percent meter is hidden by the user. */
+		new_label = g_strdup_printf ("%s\n%s",
+				DC_POWER_STRING, time_string);
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power and the battery meter
-		      and percent meter is hidden by the user.*/
-		new_label = g_strdup_printf (_("System is running on AC power\nBattery: %d%% (%s)"),
-		     batt_life, _(status[batt_state]));
+		      and percent meter is hidden by the user. */
+		new_label = g_strdup_printf ("%s\n%s",
+				AC_POWER_STRING, time_string);
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
@@ -1219,18 +1279,19 @@ change_orient (PanelApplet       *applet,
 	    /* 0 = Battery power */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power.*/
-		new_label = g_strdup (_("System is running on battery power"));
+		new_label = g_strdup (DC_POWER_STRING);
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power.*/
-		new_label = g_strdup (_("System is running on AC power"));
+		new_label = g_strdup (AC_POWER_STRING);
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
 	 g_free (new_label);
+	 g_free (time_string);
       }
    }
    
@@ -1345,13 +1406,21 @@ adj_value_changed_cb (GtkAdjustment *ignored, gpointer data)
 
 
 void
-change_size(PanelApplet *applet, gint size, gpointer data)
+size_allocate(PanelApplet *applet, GtkAllocation *allocation, gpointer data)
 {
    ProgressData *battstat = data;
    
    if (DEBUG) g_print("applet_change_pixel_size()\n");
    
-   battstat->panelsize=size;
+   if (battstat->orienttype == PANEL_APPLET_ORIENT_LEFT || battstat->orienttype == PANEL_APPLET_ORIENT_RIGHT) {
+     if (battstat->panelsize == allocation->width)
+       return;
+     battstat->panelsize = allocation->width;
+   } else {
+     if (battstat->panelsize == allocation->height)
+       return;
+     battstat->panelsize = allocation->height;
+   }
    
    battstat->colors_changed=TRUE;
    change_orient(applet, battstat->orienttype, battstat);
@@ -1448,6 +1517,7 @@ gint
 create_layout(ProgressData *battstat)
 {
    int i;
+   GtkWidget *vbox;
    
    if (DEBUG) g_print("create_layout()\n");
    
@@ -1457,17 +1527,20 @@ create_layout(ProgressData *battstat)
 			       GTK_SHADOW_NONE);
    gtk_widget_show(battstat->framestatus);
    gtk_box_pack_start( GTK_BOX(battstat->hbox1), battstat->framestatus, 
-		       FALSE, TRUE, 0);
+		       TRUE, TRUE, 0);
    
    battstat->eventstatus = gtk_event_box_new ();
    gtk_widget_show (battstat->eventstatus);
    gtk_container_add (GTK_CONTAINER (battstat->framestatus), 
 		      battstat->eventstatus);
    
+   /* Intermediate vbox to get the 'status' and 'charge' indicators centered. */
+   vbox = gtk_vbox_new (FALSE, 0);
+   gtk_container_add(GTK_CONTAINER(battstat->eventstatus),
+		     vbox);
    battstat->statusvbox = gtk_vbox_new ( FALSE, 5);
-   gtk_widget_show (battstat->statusvbox);
-   gtk_container_add(GTK_CONTAINER(battstat->eventstatus), 
-		     battstat->statusvbox);
+   gtk_box_pack_start (GTK_BOX(vbox), battstat->statusvbox, TRUE, FALSE, 0);
+   gtk_widget_show_all (vbox);
    
    battstat->framebattery = gtk_frame_new(NULL);
    /*gtk_widget_set_usize( battstat->framebattery, -1, 24);*/
@@ -1475,7 +1548,7 @@ create_layout(ProgressData *battstat)
 			       GTK_SHADOW_NONE);
    gtk_widget_show(battstat->framebattery);
    gtk_box_pack_start(GTK_BOX(battstat->hbox1), battstat->framebattery, 
-		      FALSE, TRUE, 0);
+		      TRUE, TRUE, 0);
    
    battstat->eventbattery = gtk_event_box_new();
    gtk_widget_show (battstat->eventbattery);
@@ -1512,13 +1585,13 @@ create_layout(ProgressData *battstat)
 						    battstat->mask );
    battstat->pixmapwidy = gtk_image_new_from_pixmap( battstat->pixmapy,
 						     battstat->masky );
-   gtk_box_pack_start (GTK_BOX (battstat->hbox), GTK_WIDGET (battstat->pixmapwid), FALSE, TRUE, 0);
+   gtk_box_pack_start (GTK_BOX (battstat->hbox), GTK_WIDGET (battstat->pixmapwid), TRUE, FALSE, 0);
    gtk_widget_show ( GTK_WIDGET (battstat->pixmapwid) );
 
    battstat->frameybattery = gtk_frame_new(NULL);
    /*gtk_widget_set_usize( battstat->frameybattery, 24, 46);*/
    gtk_frame_set_shadow_type ( GTK_FRAME (battstat->frameybattery), GTK_SHADOW_NONE);
-   gtk_box_pack_start(GTK_BOX(battstat->hbox1), battstat->frameybattery, FALSE, TRUE, 0);
+   gtk_box_pack_start(GTK_BOX(battstat->hbox1), battstat->frameybattery, TRUE, FALSE, 0);
    battstat->eventybattery = gtk_event_box_new();
    gtk_widget_show (battstat->eventybattery);
    gtk_container_add (GTK_CONTAINER (battstat->frameybattery), battstat->eventybattery);
@@ -1534,7 +1607,7 @@ create_layout(ProgressData *battstat)
    
    battstat->percent = gtk_label_new ("0%");
    gtk_widget_show(battstat->percent);
-   gtk_box_pack_start (GTK_BOX(battstat->hbox), battstat->percent, FALSE, TRUE, 0);
+   gtk_box_pack_start (GTK_BOX(battstat->hbox), battstat->percent, TRUE, TRUE, 0);
    
    statusimage[BATTERY] = gdk_pixmap_create_from_xpm_d( battstat->applet->window,
 							&statusmask[BATTERY],
@@ -1622,8 +1695,8 @@ create_layout(ProgressData *battstat)
 		     battstat);
 
    g_signal_connect (battstat->applet,
-		     "change_size",
-   		     G_CALLBACK (change_size),
+		     "size_allocate",
+   		     G_CALLBACK (size_allocate),
 		     battstat);
 
    g_signal_connect (battstat->applet,
