@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.89 2004/07/26 00:11:44 gowen Exp $ */
+/* $Id: weather.c,v 1.91 2004/08/16 08:44:40 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -57,6 +57,7 @@ static gboolean weather_radar = FALSE;
 #define WINDSPEED_KNOTS_TO_MPH(knots)  ((knots) * 1.150779)
 #define WINDSPEED_KNOTS_TO_MS(knots)   ((knots) * 0.514444)
 
+#define PRESSURE_INCH_TO_KPA(inch)   ((inch) * 3.386)
 #define PRESSURE_INCH_TO_HPA(inch)   ((inch) * 33.86)
 #define PRESSURE_INCH_TO_MM(inch)    ((inch) * 25.40005)
 #define PRESSURE_INCH_TO_MB(inch)    (PRESSURE_INCH_TO_HPA(inch))
@@ -1840,7 +1841,7 @@ static void wx_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
 	
     body = g_malloc0(DATA_SIZE);
 
-    info->radar_buffer = NULL;	
+    info->radar_buffer = NULL;
     info->radar = NULL;
     loc = info->location;
     g_return_if_fail(loc != NULL);
@@ -1906,7 +1907,6 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     	info->location = weather_location_clone(location);
     } else {
         location = info->location;
-        /* g_free(info->forecast); */
 	    if (info->forecast)
 	    	g_free (info->forecast);
 	    info->forecast = NULL;
@@ -2360,6 +2360,10 @@ const gchar *weather_info_get_pressure (WeatherInfo *info)
             /* TRANSLATOR: This is pressure in millimeters of mercury */
             g_snprintf (buf, sizeof (buf), _("%.1f mmHg"), PRESSURE_INCH_TO_MM(info->pressure));
             break;
+        case PRESSURE_UNIT_KPA:
+            /* TRANSLATOR: This is pressure in kiloPascals */
+            g_snprintf (buf, sizeof (buf), _("%.2f kPa"), PRESSURE_INCH_TO_KPA(info->pressure));
+            break;
         case PRESSURE_UNIT_HPA:
             /* TRANSLATOR: This is pressure in hectoPascals */
             g_snprintf (buf, sizeof (buf), _("%.2f hPa"), PRESSURE_INCH_TO_HPA(info->pressure));
