@@ -31,9 +31,6 @@
 #include "remote-helper.h"
 #include "mailcheck.h"
 
-#include "egg-screen-help.h"
-#include "egg-screen-exec.h"
-
 #define ENCODE 1  
 #define DECODE 0
 
@@ -216,7 +213,7 @@ memchunkAlloc(int size)
 
 		if (tmp->data == (char *) 0) {
 			free(tmp);
-			tmp = 0;
+			tmp = NULL;
 		}
 	}
 
@@ -310,7 +307,7 @@ b64dec(const char *string)
 
 /* return a decoded memchunk, or a null pointer in case of failure */
 
-	memchunk *rc = 0;
+	memchunk *rc = NULL;
 
 	if (string) {
 	register int length = strlen(string);
@@ -344,7 +341,7 @@ b64dec(const char *string)
 							 * no '=' should be
 							 * here */
 							if (rem < 2)
-								return 0;
+								return NULL;
 
 							/* end-of-message
 							 * recognized */
@@ -352,7 +349,7 @@ b64dec(const char *string)
 						} else {
 							/* Transmission error */
 
-							return 0;
+							return NULL;
 						}
 					}
 
@@ -2312,7 +2309,7 @@ phelp_cb (GtkDialog *w, gint tab, MailCheck *mc)
      						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 			applet_program, "mailcheck", "mailcheck", "mailcheck-prefs",
 			gtk_widget_get_screen (GTK_WIDGET (mc->applet)),
 			&error);
@@ -2488,7 +2485,10 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 				     documenters,
    				     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				     pixbuf);
-				     
+
+	if (pixbuf)
+		g_object_unref (pixbuf);
+
 	gtk_window_set_wmclass (GTK_WINDOW (mc->about), "mailcheck", "Mailcheck");
 
 	gtk_window_set_screen (GTK_WINDOW (mc->about),
@@ -2503,35 +2503,38 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 	gtk_widget_show(mc->about);
 }
 
-/*this is when the panel size changes */
 static void
-applet_change_pixel_size(PanelApplet * w, gint size, gpointer data)
+applet_size_allocate (PanelApplet *w, GtkAllocation *allocation, MailCheck *mc)
 {
-	MailCheck *mc = data;
 	const char *fname;
-	
+
 	switch (panel_applet_get_orient (w)) {
-     	case PANEL_APPLET_ORIENT_DOWN:
-        case PANEL_APPLET_ORIENT_UP:
-        	gtk_widget_set_size_request (mc->label, -1, size);
-        	break;
-     	case PANEL_APPLET_ORIENT_LEFT:
-     	case PANEL_APPLET_ORIENT_RIGHT:
-     		gtk_widget_set_size_request (mc->label, size, -1);
+	case PANEL_APPLET_ORIENT_DOWN:
+	case PANEL_APPLET_ORIENT_UP:
+		if( mc->size == allocation->height )
+			return;
+
+		mc->size = allocation->height;
+		gtk_widget_set_size_request (mc->label, -1, mc->size);
+		break;
+
+	case PANEL_APPLET_ORIENT_LEFT:
+	case PANEL_APPLET_ORIENT_RIGHT:
+		if( mc->size == allocation->width )
+			return;
+
+		mc->size = allocation->width;
+		gtk_widget_set_size_request (mc->label, mc->size, -1);
 		break;
 	}
-	if(mc->report_mail_mode == REPORT_MAIL_USE_TEXT) {
-		
-		return;
-	}
 
-	mc->size = size;
 	fname = mail_animation_filename (mc);
 
 	gtk_widget_set_size_request (GTK_WIDGET(mc->da), mc->size, mc->size);
-	
+
 	if (!fname)
 		return;
+
 	mailcheck_load_animation (mc, fname);
 }
 
@@ -2600,7 +2603,7 @@ help_callback (BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 		applet_program, "mailcheck", "mailcheck",NULL,
 		gtk_widget_get_screen (GTK_WIDGET (mc->applet)),
 		&error);
@@ -2851,8 +2854,8 @@ mailcheck_applet_fill (PanelApplet *applet)
 
 	mc->size = panel_applet_get_size (applet);
 
-	g_signal_connect(G_OBJECT(applet), "change_size",
-			 G_CALLBACK(applet_change_pixel_size),
+	g_signal_connect(G_OBJECT(applet), "size_allocate",
+			 G_CALLBACK(applet_size_allocate),
 			 mc);
 			 
 	g_signal_connect(G_OBJECT(applet), "change_orient",
