@@ -368,7 +368,7 @@ phelp_cb (GtkDialog *dialog)
 {
 	GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"modemlights", "modemlights-prefs",
 		gtk_window_get_screen (GTK_WINDOW (dialog)),
 		&error);
